menu
pl_notifications package
documentation
pl_notification_message.dart
pl_notification_message.dart
dark_mode
light_mode
pl_notification_message
library
Classes
PlNotificationMessage
Class with information to define a notification message. If the widget property is set, will present that widget, if not, will present the Notifications base widget which is a ListTile
pl_notifications package
documentation
pl_notification_message.dart
pl_notifications
package
Libraries
pl_notification_container
pl_notification_message
pl_notifications
pl_notification_message library