PlNotificationMessage class
Class with information to define a notification message. If the widget property is set, will present that widget, if not, will present the Notifications base widget which is a ListTile
Constructors
- PlNotificationMessage({Widget? title, required Duration duration, Widget? icon, Widget? subtitle, required Widget builder(PlNotificationMessage)?})
Properties
- builder → Widget Function(PlNotificationMessage)?
-
final
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → Widget?
-
final
- title → Widget?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited